"""
    File for setting the view classes used from the api_admin django app.
"""


from shared_models.models import ButtonBox, ButtonBoxUse
from shared_models.serializers import ButtonBoxSerializer, ButtonBoxUseSerializer
from rest_framework import generics, status
from rest_framework.response import Response
from rest_framework.permissions import IsAuthenticated

from backend.settings import DEFAULT_DJANGO_DEBUG


class AdminButtonBoxListCreateDeleteView(generics.ListCreateAPIView):
    """Class for setting the API views for Create, Read and Delete the entries at the ButtonBox model.
    """

    permission_classes = [IsAuthenticated]

    queryset = ButtonBox.objects.all()
    serializer_class = ButtonBoxSerializer

    def delete(self, request, *args, **kwargs):
        """Method for deleting all ButtonBox model objects.
        """

        # Delete only by debug mode
        if DEFAULT_DJANGO_DEBUG:
            ButtonBox.objects.all().delete()
            return Response(status=status.HTTP_204_NO_CONTENT)
        
        else:
            ret_dict = {
                "error": False,
                "message": "You can only delete all in debub mode --> set the 'DEFAULT_DJANGO_DEBUG' to 'True'"
            }
            return Response(ret_dict, status=status.HTTP_412_PRECONDITION_FAILED)


class AdminButtonBoxRetrieveUpdateDestroyView(generics.RetrieveUpdateDestroyAPIView):
    """Class for setting the API views for Updating entries at the ButtonBox model.
    """

    permission_classes = [IsAuthenticated]

    queryset = ButtonBox.objects.all()
    serializer_class = ButtonBoxSerializer
    ### pk --> primary_key
    lookup_field = "pk"


class AdminButtonBoxUseListCreateView(generics.ListCreateAPIView):
    """Class for setting the API views for Creating entries at the ButtonBoxUse model.
    """

    permission_classes = [IsAuthenticated]

    queryset = ButtonBoxUse.objects.all()
    serializer_class = ButtonBoxUseSerializer

    def delete(self, request, *args, **kwargs):
        """Method for deleting all ButtonBoxUse model objects.
        """

        # Delete only by debug mode
        if DEFAULT_DJANGO_DEBUG:
            ButtonBoxUse.objects.all().delete()
            return Response(status=status.HTTP_204_NO_CONTENT)
        
        else:
            ret_dict = {
                "error": False,
                "message": "You can only delete all in debub mode --> set the 'DEFAULT_DJANGO_DEBUG' to 'True'"
            }
            return Response(ret_dict, status=status.HTTP_412_PRECONDITION_FAILED)
